.. _ACID:

ACID API
=========

.. currentmodule:: ACID_code_v2

Core Classes
-------------

.. autosummary::
   :toctree: _api
   :nosignatures:

   Acid
   Result

Utility Functions
------------------

.. autosummary::
   :toctree: _api
   :nosignatures:

   calc_deltav
   guess_SNR
   scale_spectra

Legacy ACID Functions
----------------------

These functions are retained for backwards compatibility with ACID v1.

.. autosummary::
   :toctree: _api
   :nosignatures:

   ACID
   ACID_HARPS
